import { AbortablePromise, PubSub } from 'parallel-universe';
import type { ExecutorManager } from './ExecutorManager.js';
import type { Executor, ExecutorAnnotations, ExecutorEvent, ExecutorState, ExecutorTask, PartialExecutorEvent } from './types.js';
/**
 * The {@link Executor} implementation returned by the {@link ExecutorManager}.
 *
 * @internal
 */
export declare class ExecutorImpl<Value = any> implements Executor {
    readonly key: unknown;
    readonly manager: ExecutorManager;
    value: Value | undefined;
    reason: any;
    task: ExecutorTask<Value> | null;
    settledAt: number;
    invalidatedAt: number;
    isFulfilled: boolean;
    annotations: ExecutorAnnotations;
    version: number;
    promise: AbortablePromise<Value> | null;
    /**
     * The number of times the executor was activated.
     */
    _activationCount: number;
    /**
     * The pubsub that handles the executor subscriptions.
     */
    _pubSub: PubSub<ExecutorEvent<any>>;
    get isRejected(): boolean;
    get isSettled(): boolean;
    get isActive(): boolean;
    get isPending(): boolean;
    get isInvalidated(): boolean;
    constructor(key: unknown, manager: ExecutorManager);
    get(): Value;
    getOrDefault<DefaultValue>(defaultValue?: DefaultValue): Value | DefaultValue | undefined;
    getOrAwait(): AbortablePromise<Value>;
    execute(task: ExecutorTask<Value>): AbortablePromise<Value>;
    retry(): void;
    clear(): void;
    abort(reason?: unknown): void;
    invalidate(invalidatedAt?: number): void;
    resolve(value: PromiseLike<Value> | Value, settledAt?: number): void;
    reject(reason: any, settledAt?: number): void;
    activate(): () => void;
    subscribe(listener: (event: ExecutorEvent<Value>) => void): () => void;
    publish(event: PartialExecutorEvent): void;
    annotate(patch: ExecutorAnnotations): void;
    toJSON(): ExecutorState<Value>;
}
