import type { ExecutorManager } from './ExecutorManager.js';
import type { ExecutorState } from './types.js';
/**
 * Options provided to {@link enableSSRHydration}.
 */
export interface SSRHydrationOptions {
    /**
     * Parses the executor state that was captured during SSR.
     *
     * @param stateStr The state to parse.
     */
    stateParser?: (stateStr: string) => ExecutorState;
}
/**
 * Enables the SSR hydration for the given executor.
 *
 * **Note:** SSR hydration can be enabled only for one executor manager.
 *
 * @param manager The executor manager for which SSR hydration must be enabled.
 * @param options Additional options.
 * @returns The provided executor manager.
 * @template T The executor manager.
 */
export declare function enableSSRHydration<T extends ExecutorManager>(manager: T, options?: SSRHydrationOptions): T;
