/**
 * The observable that emits `true` if
 * [the device is _connected_ to the network](https://developer.mozilla.org/en-US/docs/Web/API/Navigator/onLine), and
 * emits `false` if the device is disconnected from the network.
 *
 * ```ts
 * import retryWhen from 'react-executor/plugin/retryWhen';
 * import navigatorOnline from 'react-executor/observable/navigatorOnline';
 *
 * const executor = useExecutor('test', heavyTask, [
 *   retryWhen(navigatorOnline)
 * ]);
 * ```
 *
 * @module observable/navigatorOnline
 */
import type { Observable } from '../types.js';
/**
 * The observable that emits `true` if
 * [the device is _connected_ to the network](https://developer.mozilla.org/en-US/docs/Web/API/Navigator/onLine), and
 * emits `false` if the device is disconnected from the network.
 */
declare const navigatorOnline: Observable<boolean>;
export default navigatorOnline;
