/**
 * The observable that emits `true` when
 * [the window receives focus](https://developer.mozilla.org/en-US/docs/Web/API/Document/visibilityState), and emits
 * `false` when the window looses focus.
 *
 * ```ts
 * import retryWhen from 'react-executor/plugin/retryWhen';
 * import windowFocused from 'react-executor/observable/windowFocused';
 *
 * const executor = useExecutor('test', heavyTask, [
 *   retryWhen(windowFocused)
 * ]);
 * ```
 *
 * @module observable/windowFocused
 */
import type { Observable } from '../types.js';
/**
 * The observable that emits `true` when
 * [the window receives focus](https://developer.mozilla.org/en-US/docs/Web/API/Document/visibilityState), and emits
 * `false` when the window looses focus.
 */
declare const windowFocused: Observable<boolean>;
export default windowFocused;
