"use strict";
/**
 * Aborts the pending task after the delay if the executor is deactivated.
 *
 * The executor must be activated at least once for this plugin to have an effect.
 *
 * ```ts
 * import abortDeactivated from 'react-executor/plugin/abortDeactivated';
 *
 * const executor = useExecutor('test', heavyTask, [abortDeactivated()]);
 * ```
 *
 * @module plugin/abortDeactivated
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = abortDeactivated;
const utils_js_1 = require("../utils.js");
/**
 * Aborts the pending task after the {@link AbortDeactivatedOptions.delay delay} if the executor is deactivated.
 *
 * The executor must be activated at least once for this plugin to have an effect.
 *
 * @param options Abort options.
 */
function abortDeactivated(options = utils_js_1.emptyObject) {
    const { delay = 0 } = options;
    return executor => {
        let timer;
        executor.subscribe(event => {
            switch (event.type) {
                case 'deactivated':
                    clearTimeout(timer);
                    timer = setTimeout(() => executor.abort(), delay);
                    break;
                case 'activated':
                case 'detached':
                    clearTimeout(timer);
                    break;
            }
        });
        executor.publish({
            type: 'plugin_configured',
            payload: {
                type: 'abortDeactivated',
                options: { delay },
            },
        });
    };
}
