/**
 * The plugin that aborts the pending task with {@link !DOMException TimeoutError} if the task execution took longer
 * then the given delay.
 *
 * ```ts
 * import abortPendingAfter from 'react-executor/plugin/abortPendingAfter';
 *
 * const executor = useExecutor('test', heavyTask, [
 *   abortPendingAfter(10_000)
 * ]);
 * ```
 *
 * @module plugin/abortPendingAfter
 */
import type { ExecutorPlugin } from '../types.js';
/**
 * Aborts the pending task with {@link !DOMException TimeoutError} if the task execution took longer then the given
 * delay.
 *
 * @param delay The delay in milliseconds after which the task is aborted.
 */
export default function abortPendingAfter(delay: number): ExecutorPlugin;
