"use strict";
/**
 * The plugin that aborts the pending task with {@link !DOMException TimeoutError} if the task execution took longer
 * then the given delay.
 *
 * ```ts
 * import abortPendingAfter from 'react-executor/plugin/abortPendingAfter';
 *
 * const executor = useExecutor('test', heavyTask, [
 *   abortPendingAfter(10_000)
 * ]);
 * ```
 *
 * @module plugin/abortPendingAfter
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = abortPendingAfter;
const utils_js_1 = require("../utils.js");
/**
 * Aborts the pending task with {@link !DOMException TimeoutError} if the task execution took longer then the given
 * delay.
 *
 * @param delay The delay in milliseconds after which the task is aborted.
 */
function abortPendingAfter(delay) {
    return executor => {
        let timer;
        executor.subscribe(event => {
            switch (event.type) {
                case 'pending':
                    clearTimeout(timer);
                    timer = setTimeout(() => executor.abort((0, utils_js_1.TimeoutError)('The task execution took too long')), delay);
                    break;
                case 'fulfilled':
                case 'rejected':
                case 'aborted':
                case 'detached':
                    clearTimeout(timer);
                    break;
            }
        });
        executor.publish({
            type: 'plugin_configured',
            payload: {
                type: 'abortPendingAfter',
                options: { delay },
            },
        });
    };
}
