"use strict";
/**
 * The plugin that detaches a deactivated executor after a delay. The executor must be activated at least once
 * for this plugin to have an effect.
 *
 * ```ts
 * import detachDeactivated from 'react-executor/plugin/detachDeactivated';
 *
 * const executor = useExecutor('test', 42, [detachDeactivated()]);
 * ```
 *
 * @module plugin/detachDeactivated
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = detachDeactivated;
const detachInactive_js_1 = require("./detachInactive.js");
const utils_js_1 = require("../utils.js");
/**
 * Detaches a deactivated executor after a {@link DetachDeactivatedOptions.delay delay}. The executor must be activated
 * at least once for this plugin to have an effect.
 *
 * @param options Detach options.
 * @see {@link detachInactive}
 */
function detachDeactivated(options = utils_js_1.emptyObject) {
    const { delay = 5000 } = options;
    return (0, detachInactive_js_1.default)({ delayAfterDeactivation: delay });
}
