/**
 * The plugin that detaches a deactivated executor after a delay. The executor must be activated at least once
 * for this plugin to have an effect.
 *
 * ```ts
 * import detachDeactivated from 'react-executor/plugin/detachDeactivated';
 *
 * const executor = useExecutor('test', 42, [detachDeactivated()]);
 * ```
 *
 * @module plugin/detachDeactivated
 */
import detachInactive from './detachInactive.mjs';
import { emptyObject } from '../utils.mjs';
/**
 * Detaches a deactivated executor after a {@link DetachDeactivatedOptions.delay delay}. The executor must be activated
 * at least once for this plugin to have an effect.
 *
 * @param options Detach options.
 * @see {@link detachInactive}
 */
export default function detachDeactivated(options = emptyObject) {
    const { delay = 5000 } = options;
    return detachInactive({ delayAfterDeactivation: delay });
}
