/**
 * The plugin that invalidates the executor result if another executor is fulfilled or invalidated.
 *
 * ```ts
 * import invalidateByPeers from 'react-executor/plugin/invalidateByPeers';
 *
 * const executor = useExecutor('test', 42, [
 *   invalidateByPeers(executor => executor.key === 'exact_executor_key')
 * ]);
 * ```
 *
 * @module plugin/invalidateByPeers
 */
import type { Executor, ExecutorPlugin } from '../types.js';
/**
 * Invalidates the executor result if another executor is fulfilled or invalidated.
 *
 * @param peerMatcher A collection of peer executors or a callback that returns a truthy value for a matching peer
 * executor.
 */
export default function invalidateByPeers(peerMatcher: Iterable<Executor> | ((executor: Executor) => any)): ExecutorPlugin;
