/**
 * The plugin that invalidates peer executors with matching keys if the executor is fulfilled or invalidated.
 *
 * ```ts
 * import invalidatePeers from 'react-executor/plugin/invalidatePeers';
 *
 * const executor = useExecutor('test', 42, [
 *   invalidatePeers(executor => executor.key === 'exact_executor_key')
 * ]);
 * ```
 *
 * @module plugin/invalidatePeers
 */
import type { Executor, ExecutorPlugin } from '../types.js';
/**
 * Invalidates peer executors with matching keys if the executor is fulfilled or invalidated.
 *
 * @param peerMatcher The callback that returns a truthy value for a matching peer executor.
 */
export default function invalidatePeers(peerMatcher: Iterable<Executor> | ((executor: Executor) => any)): ExecutorPlugin;
