/**
 * The plugin that aborts the pending task and rejects the executor with {@link !DOMException TimeoutError} if the task
 * execution took longer then the delay.
 *
 * ```ts
 * import rejectPendingAfter from 'react-executor/plugin/rejectPendingAfter';
 *
 * const executor = useExecutor('test', heavyTask, [
 *   rejectPendingAfter(10_000)
 * ]);
 * ```
 *
 * @module plugin/rejectPendingAfter
 */
import type { ExecutorPlugin } from '../types.js';
/**
 * Aborts the pending task and rejects the executor with {@link !DOMException TimeoutError} if the task execution took
 * longer then the delay.
 *
 * @param delay The delay in milliseconds after which the executor is rejected.
 */
export default function rejectPendingAfter(delay: number): ExecutorPlugin;
