/**
 * The plugin that resolves the executor with values pushed by an observable.
 *
 * ```ts
 * import resolveBy from 'react-executor/plugin/resolveBy';
 *
 * const executor = useExecutor('test', heavyTask, [
 *   resolveBy(observable)
 * ]);
 * ```
 *
 * @module plugin/resolveBy
 */
import type { ExecutorPlugin, Observable } from '../types.js';
/**
 * Resolves the executor with values pushed by an observable.
 *
 * @param observable The observable that pushes values.
 * @template Value The value stored by the executor.
 */
export default function resolveBy<Value>(observable: Observable<PromiseLike<Value> | Value>): ExecutorPlugin<Value>;
