"use strict";
/**
 * The plugin that retries the latest task if the executor is activated.
 *
 * ```ts
 * import retryActivated from 'react-executor/plugin/retryActivated';
 *
 * const executor = useExecutor('test', () => 42, [retryActivated()]);
 *
 * executor.activate();
 * ```
 *
 * @module plugin/retryActivated
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = retryActivated;
const utils_js_1 = require("../utils.js");
/**
 * Retries the latest task if the executor is activated.
 *
 * @param options Retry options.
 */
function retryActivated(options = utils_js_1.emptyObject) {
    const { staleDelay = 0 } = options;
    return executor => {
        executor.subscribe(event => {
            if (event.type === 'activated' && Date.now() - executor.settledAt >= staleDelay) {
                executor.retry();
            }
        });
        executor.publish({
            type: 'plugin_configured',
            payload: {
                type: 'retryActivated',
                options: { staleDelay },
            },
        });
    };
}
