/**
 * The plugin that retries the latest task if the executor is activated.
 *
 * ```ts
 * import retryActivated from 'react-executor/plugin/retryActivated';
 *
 * const executor = useExecutor('test', () => 42, [retryActivated()]);
 *
 * executor.activate();
 * ```
 *
 * @module plugin/retryActivated
 */
import { emptyObject } from '../utils.mjs';
/**
 * Retries the latest task if the executor is activated.
 *
 * @param options Retry options.
 */
export default function retryActivated(options = emptyObject) {
    const { staleDelay = 0 } = options;
    return executor => {
        executor.subscribe(event => {
            if (event.type === 'activated' && Date.now() - executor.settledAt >= staleDelay) {
                executor.retry();
            }
        });
        executor.publish({
            type: 'plugin_configured',
            payload: {
                type: 'retryActivated',
                options: { staleDelay },
            },
        });
    };
}
