/**
 * The plugin that retries the last task if the executor is fulfilled.
 *
 * ```ts
 * import retryFulfilled from 'react-executor/plugin/retryFulfilled';
 *
 * const executor = useExecutor('test', heavyTask, [retryFulfilled()]);
 * ```
 *
 * @module plugin/retryFulfilled
 */
import type { Executor, ExecutorPlugin } from '../types.js';
/**
 * Options of the {@link retryFulfilled} plugin.
 *
 * @template Value The value stored by the executor.
 */
export interface RetryFulfilledOptions<Value> {
    /**
     * The number of repetitions.
     *
     * @default Infinity
     */
    count?: number;
    /**
     * The delay in milliseconds after which the repetition is scheduled.
     *
     * @default 5_000
     */
    delay?: number | ((index: number, executor: Executor<Value>) => number);
    /**
     * If `true` then executor is retried even if it isn't {@link Executor.isActive active}.
     *
     * @default false
     */
    isEager?: boolean;
}
/**
 * Retries the last task if the executor is fulfilled.
 *
 * @param options Retry options.
 * @template Value The value stored by the executor.
 */
export default function retryFulfilled<Value = any>(options?: RetryFulfilledOptions<Value>): ExecutorPlugin<Value>;
