/**
 * The plugin that retries the last task if the executor is invalidated.
 *
 * ```ts
 * import retryInvalidated from 'react-executor/plugin/retryInvalidated';
 *
 * const executor = useExecutor('test', heavyTask, [retryInvalidated()]);
 * ```
 *
 * @module plugin/retryInvalidated
 */
import type { ExecutorPlugin } from '../types.js';
/**
 * Options of the {@link retryInvalidated} plugin.
 */
export interface RetryInvalidatedOptions {
    /**
     * If `true` then executor is retried even if it isn't active.
     *
     * @default false
     */
    isEager?: boolean;
}
/**
 * Retries the last task if the executor is invalidated.
 */
export default function retryInvalidated(options?: RetryInvalidatedOptions): ExecutorPlugin;
