"use strict";
/**
 * The plugin that retries the last task if the executor is invalidated.
 *
 * ```ts
 * import retryInvalidated from 'react-executor/plugin/retryInvalidated';
 *
 * const executor = useExecutor('test', heavyTask, [retryInvalidated()]);
 * ```
 *
 * @module plugin/retryInvalidated
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = retryInvalidated;
const utils_js_1 = require("../utils.js");
/**
 * Retries the last task if the executor is invalidated.
 */
function retryInvalidated(options = utils_js_1.emptyObject) {
    const { isEager = false } = options;
    return executor => {
        executor.subscribe(event => {
            if ((event.type === 'invalidated' && (isEager || executor.isActive)) ||
                (event.type === 'activated' && executor.isInvalidated)) {
                executor.retry();
            }
        });
        executor.publish({
            type: 'plugin_configured',
            payload: {
                type: 'retryInvalidated',
                options: { isEager },
            },
        });
    };
}
