/**
 * The plugin that retries the last task if the executor is invalidated.
 *
 * ```ts
 * import retryInvalidated from 'react-executor/plugin/retryInvalidated';
 *
 * const executor = useExecutor('test', heavyTask, [retryInvalidated()]);
 * ```
 *
 * @module plugin/retryInvalidated
 */
import { emptyObject } from '../utils.mjs';
/**
 * Retries the last task if the executor is invalidated.
 */
export default function retryInvalidated(options = emptyObject) {
    const { isEager = false } = options;
    return executor => {
        executor.subscribe(event => {
            if ((event.type === 'invalidated' && (isEager || executor.isActive)) ||
                (event.type === 'activated' && executor.isInvalidated)) {
                executor.retry();
            }
        });
        executor.publish({
            type: 'plugin_configured',
            payload: {
                type: 'retryInvalidated',
                options: { isEager },
            },
        });
    };
}
