/**
 * The plugin that retries the last task if it has is failed.
 *
 * ```ts
 * import retryRejected from 'react-executor/plugin/retryRejected';
 *
 * const executor = useExecutor('test', heavyTask, [retryRejected()]);
 * ```
 *
 * @module plugin/retryRejected
 */
import type { Executor, ExecutorPlugin } from '../types.js';
/**
 * Options of the {@link retryRejected} plugin.
 *
 * @template Value The value stored by the executor.
 */
export interface RetryRejectedOptions<Value> {
    /**
     * The number of times the task must be repeated if it fails.
     *
     * @default 3
     */
    count?: number;
    /**
     * The delay in milliseconds after which the retry is scheduled.
     *
     * By default, an exponential backoff is used.
     */
    delay?: number | ((index: number, executor: Executor<Value>) => number);
    /**
     * If `true` then executor is retried even if it isn't {@link Executor.isActive active}.
     *
     * @default false
     */
    isEager?: boolean;
}
/**
 * Retries the last task if it has is failed.
 *
 * @param options Retry options.
 * @template Value The value stored by the executor.
 */
export default function retryRejected<Value = any>(options?: RetryRejectedOptions<Value>): ExecutorPlugin<Value>;
