"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReadableSSRExecutorManager = void 0;
const SSRExecutorManager_js_1 = require("./SSRExecutorManager.js");
/**
 * The streaming executor manager that can be used as a transformer for
 * [Web Streams](https://developer.mozilla.org/en-US/docs/Web/API/Streams_API). It enqueues executor hydration chunks
 * into the after each chunk from the read side.
 */
class ReadableSSRExecutorManager extends SSRExecutorManager_js_1.SSRExecutorManager {
    /**
     * Creates a new {@link ReadableSSRExecutorManager} instance.
     *
     * @param options Additional options.
     */
    constructor(options) {
        super(options);
        const transformer = new TransformStream({
            transform: (chunk, controller) => {
                controller.enqueue(chunk);
                if (!chunk.toString().endsWith('</script>')) {
                    return;
                }
                const hydrationChunk = this.nextHydrationChunk();
                if (hydrationChunk !== '') {
                    controller.enqueue(hydrationChunk);
                }
            },
        });
        this.readable = transformer.readable;
        this.writable = transformer.writable;
    }
}
exports.ReadableSSRExecutorManager = ReadableSSRExecutorManager;
