"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PipeableSSRExecutorManager = void 0;
const stream_1 = require("stream");
const SSRExecutorManager_js_1 = require("../SSRExecutorManager.js");
/**
 * Streaming executor manager for NodeJS environment.
 */
class PipeableSSRExecutorManager extends SSRExecutorManager_js_1.SSRExecutorManager {
    /**
     * Creates a new {@link PipeableSSRExecutorManager} instance.
     *
     * @param stream The output stream to which both React chunks and executor hydration chunks are written.
     * @param options Additional options.
     */
    constructor(stream, options) {
        super(options);
        this.stream = new stream_1.Writable({
            write: (chunk, encoding, callback) => {
                stream.write(chunk, encoding, error => {
                    if (error) {
                        callback(error);
                        return;
                    }
                    if (!chunk.toString().endsWith('</script>')) {
                        callback();
                        return;
                    }
                    const hydrationChunk = this.nextHydrationChunk();
                    if (hydrationChunk !== '') {
                        stream.write(hydrationChunk, callback);
                        return;
                    }
                    callback();
                });
            },
            final: callback => {
                stream.end(callback);
            },
        });
    }
}
exports.PipeableSSRExecutorManager = PipeableSSRExecutorManager;
