import { Writable } from 'stream';
import { SSRExecutorManager } from '../SSRExecutorManager.mjs';
/**
 * Streaming executor manager for NodeJS environment.
 */
export class PipeableSSRExecutorManager extends SSRExecutorManager {
    /**
     * Creates a new {@link PipeableSSRExecutorManager} instance.
     *
     * @param stream The output stream to which both React chunks and executor hydration chunks are written.
     * @param options Additional options.
     */
    constructor(stream, options) {
        super(options);
        this.stream = new Writable({
            write: (chunk, encoding, callback) => {
                stream.write(chunk, encoding, error => {
                    if (error) {
                        callback(error);
                        return;
                    }
                    if (!chunk.toString().endsWith('</script>')) {
                        callback();
                        return;
                    }
                    const hydrationChunk = this.nextHydrationChunk();
                    if (hydrationChunk !== '') {
                        stream.write(hydrationChunk, callback);
                        return;
                    }
                    callback();
                });
            },
            final: callback => {
                stream.end(callback);
            },
        });
    }
}
